AVAIABLE_RIGS = {
    'Standup L-Set Advanced Component Manufacturing Efficiency I',
    'Standup L-Set Advanced Large Ship Manufacturing Efficiency I',
    'Standup L-Set Advanced Medium Ship Manufacturing Efficiency I',
    'Standup L-Set Advanced Small Ship Manufacturing Efficiency I',
    'Standup L-Set Ammunition Manufacturing Efficiency I',
    'Standup L-Set Basic Capital Component Manufacturing Efficiency I',
    'Standup L-Set Basic Large Ship Manufacturing Efficiency I',
    'Standup L-Set Basic Medium Ship Manufacturing Efficiency I',
    'Standup L-Set Basic Small Ship Manufacturing Efficiency I',
    'Standup L-Set Capital Ship Manufacturing Efficiency I',
    'Standup L-Set Drone and Fighter Manufacturing Efficiency I',
    'Standup L-Set Equipment Manufacturing Efficiency I',
    'Standup L-Set Structure Manufacturing Efficiency I',
    'Standup L-Set Thukker Advanced Component Manufacturing Efficiency',
    'Standup L-Set Thukker Basic Capital Component Manufacturing Efficiency',
    'Standup L-Set Advanced Component Manufacturing Efficiency II',
    'Standup L-Set Advanced Large Ship Manufacturing Efficiency II',
    'Standup L-Set Advanced Medium Ship Manufacturing Efficiency II',
    'Standup L-Set Advanced Small Ship Manufacturing Efficiency II',
    'Standup L-Set Capital Ship Manufacturing Efficiency II',
    'Standup L-Set Ammunition Manufacturing Efficiency II',
    'Standup L-Set Basic Capital Component Manufacturing Efficiency II',
    'Standup L-Set Basic Large Ship Manufacturing Efficiency II',
    'Standup L-Set Basic Medium Ship Manufacturing Efficiency II',
    'Standup L-Set Basic Small Ship Manufacturing Efficiency II',
    'Standup L-Set Drone and Fighter Manufacturing Efficiency II',
    'Standup L-Set Equipment Manufacturing Efficiency II',
    'Standup L-Set Structure Manufacturing Efficiency II',
}
